/*
 *  cache-file.h
 *  mod_musicindex
 *
 *  $Id: cache-file.h 705 2007-02-27 17:09:32Z varenet $
 *
 *  Created by Thibaut VARENE on Wed Feb 23 2005.
 *  Copyright (c) 2005 Thibaut VARENE
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License version 2.1,
 *  as published by the Free Software Foundation.
 *
 */

#ifndef CACHE_FILE_H
#define CACHE_FILE_H

int cache_file_setup(cmd_parms *cmd, const char *const setup_string, mu_config *const conf);

#endif /* CACHE_FILE_H */
